#!/usr/bin/env python
##------------------------------------------------------------------------------
##
## celestial_coord_update.py
##
## We want to update celestial coordinate keywords
##    ELAT_REF, ELON_REF, GLAT_REF, GLON_REF
##
##
## History:
## mm/dd/yy PR    Who        What          
## -------- ----- ---------- --------------------------------------------------
## 01/20/09 61586 Sherbert   Create command line script 
## 08/12/09 63318 Sherbert   easier debug if don't import *
##
##------------------------------------------------------------------------------

import os
import sys
import ac_pkg
import opusutil
from opusutil_pyfits import update_coord_keywords

## Sometimes maybe you want the message to look
## like it comes from the calling program
moduleName = os.path.basename(sys.argv[0])
## but errors should specify this script
thisModule = 'celestial_coord_update'

##------------------------------------------------------------------------------
##
## Method:  usage()
##
## Description: 
##          Print usage message for celestial_coord_update(.py) 
##
## Returns: nothing
##
##------------------------------------------------------------------------------
def usage():
    usageMsg = """
            celestial_coord_update.py

            If no command-line arguments are provided, environment variables 
            must be defined for the 4 arguments.  Otherwise, the arguments are 
            expected to be in this order:

            <OSF_DATASET> <OUTPATH>

    """
    opusutil.PrintMsg('F', usageMsg, thisModule )
    return


##------------------------------------------------------------------------------
##
## Method:  doIt( envVars )
##
## Input:
##     a hash keyed on OSF_DATASET and OUTPATH
##
## Description: 
##     worker bee, heart of program, callable from another python script
##
##------------------------------------------------------------------------------
def doIt( envVars ):
    rootname = envVars["OSF_DATASET"].lower()
    msg = '-- Starting  ' + thisModule + ' for '+rootname
    opusutil.PrintMsg('I', msg, moduleName )
    ## Update celestial coordinates
    errCount = 0
    ## Which files to update?  
    ## The NIC files that have ASN_MTYP==PROD-TARG AND contain
    ## the [GE]{LAT|LON}_REF keywords are the mos and saa files.
    ## The team may not like the saa files, but we DO catalog from 
    ## them, so I am keeping them here.
    ## Do I want to hard-code those extensions, or read every NIC file?
    ## I fear opening every NIC header is going to slow this 
    ## process down a bit on our system.  Therefore hard-coded for now.
    filenames = ac_pkg.find_mos_saa( rootname )
    if len( filenames ) > 0:
        try:
            update_coord_keywords( filenames )
        except RuntimeError, errMsg:
            opusutil.PrintMsg('F', str(errMsg), moduleName)
            errCount = errCount + 1
    ## How do I want to handle an error?
    if errCount > 0:
            sys.exit(ac_pkg.QUIT_THIS_DATASET)

    msg = '-- Completed ' + thisModule + ' for '+rootname
    opusutil.PrintMsg('I', msg, moduleName )


##==============================================================================
##
## Main
##
##==============================================================================
if __name__ == "__main__":
    ac_pkg.banner()
    ## Want this script to be runnable from command line or from pipeline
    ## or callable from another python script
    envVars = {}
    needThese = ["OSF_DATASET", "OUTPATH"]
    if (len(sys.argv)) == 1:
        opusutil.PrintMsg('D', 'Processing env vars', moduleName )
        try:    
            envVars = ac_pkg.envSetUp('env', needThese)
        except RuntimeError, errMsg: 
            opusutil.PrintMsg('F', str(errMsg), thisModule )
            usage() 
            sys.exit(ac_pkg.GO_ABSENT)
    else:   
        opusutil.PrintMsg('D', 'Processing cmd line vars', moduleName )
        envVars = ac_pkg.envSetUp('cmdLine', needThese)

    ## Verify and cd to caldir
    caldir = envVars["OUTPATH"]
    try:
        ac_pkg.verify_n_cd_to_dir(caldir)
    except RuntimeError, errMsg:
        opusutil.PrintMsg('E', str(errMsg), 'ac_pkg.verify_n_cd_to_dir')
        sys.exit(ac_pkg.GO_ABSENT)

    stat = doIt(envVars)
    if stat == ac_pkg.GO_ABSENT:
        ac_pkg.banner()
        sys.exit(ac_pkg.GO_ABSENT)
    elif stat == ac_pkg.QUIT_THIS_DATASET:
        ac_pkg.banner()
        sys.exit(ac_pkg.QUIT_THIS_DATASET)

    sys.exit(ac_pkg.ALL_IS_WELL)

